Stan Math Library: stan/math/prim/mat/fun/assign.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
assign.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/err/invalid_argument.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/mat/err/check_matching_sizes.hpp>`
`#include <stan/math/prim/mat/err/check_matching_dims.hpp>`
`#include <iostream>`
`#include <sstream>`
`#include <stdexcept>`
`#include <string>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::print_mat_size (int n, std::ostream &o)
| Helper function to return the matrix size as either "dynamic" or "1". More...
template<typename LHS , typename RHS >
void | stan::math::assign (LHS &lhs, const RHS &rhs)
| Copy the right-hand side's value to the left-hand side variable. More...
template<typename LHS , typename RHS , int R1, int C1, int R2, int C2>
void | stan::math::assign (Eigen::Matrix< LHS, R1, C1 > &x, const Eigen::Matrix< RHS, R2, C2 > &y)
| Copy the right-hand side's value to the left-hand side variable. More...
template<typename LHS , typename RHS , int R, int C>
void | stan::math::assign (Eigen::Matrix< LHS, R, C > &x, const Eigen::Matrix< RHS, R, C > &y)
| Copy the right-hand side's value to the left-hand side variable. More...
template<typename LHS , typename RHS , int R, int C>
void | stan::math::assign (Eigen::Block< LHS > x, const Eigen::Matrix< RHS, R, C > &y)
| Copy the right-hand side's value to the left-hand side variable. More...
template<typename LHS , typename RHS >
void | stan::math::assign (std::vector< LHS > &x, const std::vector< RHS > &y)
| Copy the right-hand side's value to the left-hand side variable. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.